# tofupy

A Python wrapper library around OpenTofu (and Terraform).

This project was built as an example for Chapter 11 of [Terraform in Depth](https://mng.bz/QR21) in order to demonstrate how to wrap the OpenTofu or Terraform binaries to control from another language. Despite being an example, this is an active and maintained open source project that can be used for production purposes.

## Installation

Either `tofu` or `terraform` should be installed.

```bash
pip install tofupy
```
